Authorization

Derive Macro Authorization 

#[derive(Authorization)]
{
    // Attributes available to this derive:
    #[pagination]
    #[filter]
    #[sort]
    #[range]
}
The derive macro #[derive(Authorization)] is used to implement the Authorization trait by default for a struct.
The trait will not add any authorization to the Api by default.