Keycloak

Derive Macro Keycloak 

#[derive(Keycloak)]
{
    // Attributes available to this derive:
    #[auth_type]
    #[pagination]
    #[filter]
    #[sort]
    #[range]
}
The derive macro #[derive(Keycloak)] is used to implement the Authorization trait for a struct.
The trait will add the AuthorizationType authorization to the Api and will use the Keycloak service.