#[derive(Basic)]
{
// Attributes available to this derive:
#[pagination]
#[filter]
#[sort]
#[range]
}
The derive macro #[derive(Basic)] is used to implement the Authorization trait for a struct.
The trait will add Basic authorization to the Api.